require 'socket'

class Callsigns::TCP

  def self.greet(client)
    client.puts "\n\nWelcome to [Callsigns by AL0Y]"
    client.puts "This is an interactive server to search information of ham radio operators"
    client.puts "by their callsign [only USA-based], DMR ID or NXDN ID"
    help(client)
  end


  def self.help(client)
    client.puts "\n\nAvilable commands:\n"
    client.puts " Lookup [callsign]     - Gives information about the given callsign"
    client.puts "                         As of now, the callsign must be USA-Based."
    client.puts " DMR [number]          - Gives information about a DMR ID\n "
    client.puts " NXDN [number]         - Gives information about a NXDN ID"
    client.puts " HELP or ?             - Shows this command list"
    client.puts " Version               - Shows the current version for this server"
    client.puts " Bye                   - Disconnect from the Callsigns server and"
    client.puts "                         return to node."

  end

  def self.goodbye(client)
    client.puts "Thanks for using Callsigns by AL0Y. 73 de AL0Y\n\n"
  end

  def self.menu(client)
    input = nil
    while input != "bye"
      client.puts "\nPlease enter a command, or type ? for a list of commands>"
      input = client.gets.chomp.downcase
      
      if input == "bye"
        goodbye(client)
      
      elsif input == "version"
        client.puts "Callsigns by AL0Y - Version:" + Callsigns::VERSION.to_s
      
      elsif input == "?" || input == "help"
        help(client)
      
      elsif input.split(" ").count == 2 && input.split(" ")[0] == "lookup"
        lookup_callsign = input.split(" ")[1]
        client.puts "Getting information for " + lookup_callsign.to_s + "\n..."
        Callsigns::Callook.lookup(lookup_callsign, client)
      elsif input.split(" ").count == 2 && input.split(" ")[0] == "dmr"
        dmr_id = input.split(" ")[1]
        client.puts "Getting information for " + dmr_id.to_s
        Callsigns::RadioID.dmr(dmr_id, client)
      
      elsif input.split(" ").count == 2 && input.split(" ")[0] == "nxdn"
        nxdn_id = input.split(" ")[1]
        client.puts "Getting information for " + nxdn_id.to_s
        Callsigns::RadioID.nxdn(nxdn_id, client)
      
      else
        client.puts "Unknown command!"
      end

    end
  end

  def self.main(port)
    server = TCPServer.new port.to_i
    loop do
      Thread.start(server.accept) do |client| 
        greet(client)
        menu(client)
        client.close
      end
    end
  end

end